==> haskell-quickcheck-text-0.1.2.1-226-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-text
version:              0.1.2.1
visibility:           public
id:                   quickcheck-text-0.1.2.1-1Hu9Yp7jy2K9yQ26Qv89Bt
key:                  quickcheck-text-0.1.2.1-1Hu9Yp7jy2K9yQ26Qv89Bt
license:              MIT
copyright:            2015-2016 Sharif Olorin and others
maintainer:           sio@tesser.org
author:               Sharif Olorin
homepage:             https://github.com/olorin/quickcheck-text
synopsis:             Alternative arbitrary instance for Text
description:
    The usual Arbitrary instance for Text
    (in
    <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>)
    only has single-byte
    instances and so isn'\''t an ideal representation of a valid UTF-8
    character. This package has generators for one-, two- and three-byte
    UTF-8 characters (all that are currently in use).

category:             Text
abi:                  d738ea064173ef70f25c55e17f4d1f47
exposed:              True
exposed-modules:      Data.Text.Arbitrary Test.QuickCheck.Utf8
import-dirs:          /usr/lib/ghc-9.6.6/site-local/quickcheck-text-0.1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quickcheck-text-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quickcheck-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-text
hs-libraries:         HSquickcheck-text-0.1.2.1-1Hu9Yp7jy2K9yQ26Qv89Bt
depends:
    QuickCheck-2.15.0.1-LaRIQHiwv8U7w9VIoXbmQQ base-4.18.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-text/html/quickcheck-text.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-text/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-text-0.1.2.1-227-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-text
version:              0.1.2.1
visibility:           public
id:                   quickcheck-text-0.1.2.1-CxqPXVPKYK4ArVgYZKHDnq
key:                  quickcheck-text-0.1.2.1-CxqPXVPKYK4ArVgYZKHDnq
license:              MIT
copyright:            2015-2016 Sharif Olorin and others
maintainer:           sio@tesser.org
author:               Sharif Olorin
homepage:             https://github.com/olorin/quickcheck-text
synopsis:             Alternative arbitrary instance for Text
description:
    The usual Arbitrary instance for Text
    (in
    <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>)
    only has single-byte
    instances and so isn'\''t an ideal representation of a valid UTF-8
    character. This package has generators for one-, two- and three-byte
    UTF-8 characters (all that are currently in use).

category:             Text
abi:                  f71772de51d515940c856f7f3d32f0cf
exposed:              True
exposed-modules:      Data.Text.Arbitrary Test.QuickCheck.Utf8
import-dirs:          /usr/lib/ghc-9.6.6/site-local/quickcheck-text-0.1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quickcheck-text-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quickcheck-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-text
hs-libraries:         HSquickcheck-text-0.1.2.1-CxqPXVPKYK4ArVgYZKHDnq
depends:
    QuickCheck-2.15.0.1-6GEGPgW6PY5CA5PnU98uYH base-4.18.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-text/html/quickcheck-text.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-text/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
